@@ -2,15 +2,21 @@ import telegram
 from botty_core.types import Chat, Message, PTBHandler, ReplyMarkup, User
 from telegram import ext
 
+from botty.keyboards import InlineKeyboard
+
 from .update import UpdateHandler
 
 
 class MessageHandler(UpdateHandler):
     filters: ext.filters.BaseFilter = ext.filters.UpdateType.MESSAGE
-    reply_markup: ReplyMarkup | None = None
 
-    def __init__(self, reply_text: str | None = None) -> None:
+    def __init__(
+        self,
+        reply_text: str | None = None,
+        reply_keyboard: InlineKeyboard | None = None,
+    ) -> None:
         self.reply_text = reply_text
+        self.reply_keyboard = reply_keyboard
         super().__init__()
 
     def build(self) -> PTBHandler:
@@ -26,7 +32,11 @@ class MessageHandler(UpdateHandler):
         return self.reply_text
 
     def get_reply_markup(self) -> ReplyMarkup | None:
-        return self.reply_markup
+        keyboard = self.get_reply_keyboard()
+        return None if keyboard is None else keyboard.build()
+
+    def get_reply_keyboard(self) -> InlineKeyboard | None:
+        return self.reply_keyboard
 
     async def reply(
         self,
