@@ -7,6 +7,10 @@ class Texts:
         reader = Path(path).open("rb")
         self.items = tomllib.load(reader)
 
+    def get_words(self, key: int) -> list[str]:
+        text = self[key]
+        return [i.lower() for i in text.split()]
+
     def __getitem__(self, item: int) -> str:
         key = str(item)
         if key in self.items:
